@@ -1,4 +1,4 @@
-## Copyright (C) 2004, 2005, 2007, 2008, 2009 David Bateman and Andy Adler
+## Copyright (C) 2004-2013 David Bateman and Andy Adler
 ##
 ## This file is part of Octave.
 ##
@@ -17,24 +17,26 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {@var{y} =} spones (@var{x})
-## Replace the non-zero entries of @var{x} with ones.  This creates a
-## sparse matrix with the same structure as @var{x}.
+## @deftypefn {Function File} {@var{r} =} spones (@var{S})
+## Replace the non-zero entries of @var{S} with ones.  This creates a
+## sparse matrix with the same structure as @var{S}.
 ## @end deftypefn
 
-function s = spones (s)
+function r = spones (S)
 
   if (nargin != 1)
     print_usage ();
   endif
 
-  [i, j, v] = find (s);
-  [m, n] = size (s);
+  [i, j, v] = find (S);
+  [m, n] = size (S);
 
-  s = sparse (i, j, 1, m, n);
+  r = sparse (i, j, 1, m, n);
 
 endfunction
 
-%!assert(issparse(spones([1,2;3,0])))
-%!assert(spones([1,2;3,0]),sparse([1,1;1,0]))
-%!assert(spones(sparse([1,2;3,0])),sparse([1,1;1,0]))
+
+%!assert (issparse (spones ([1,2;3,0])))
+%!assert (spones ([1,2;3,0]), sparse ([1,1;1,0]))
+%!assert (spones (sparse ([1,2;3,0])), sparse ([1,1;1,0]))
+
