@@ -1,5 +1,4 @@
-## Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2002, 2003, 2005,
-##               2006, 2007, 2008, 2009 Kurt Hornik
+## Copyright (C) 1995-2013 Kurt Hornik
 ##
 ## This file is part of Octave.
 ##
@@ -18,8 +17,11 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} mean (@var{x}, @var{dim}, @var{opt})
-## If @var{x} is a vector, compute the mean of the elements of @var{x}
+## @deftypefn  {Function File} {} mean (@var{x})
+## @deftypefnx {Function File} {} mean (@var{x}, @var{dim})
+## @deftypefnx {Function File} {} mean (@var{x}, @var{opt})
+## @deftypefnx {Function File} {} mean (@var{x}, @var{dim}, @var{opt})
+## Compute the mean of the elements of the vector @var{x}.
 ## @tex
 ## $$ {\rm mean}(x) = \bar{x} = {1\over N} \sum_{i=1}^N x_i $$
 ## @end tex
@@ -28,29 +30,30 @@
 ## @example
 ## mean (x) = SUM_i x(i) / N
 ## @end example
+##
 ## @end ifnottex
 ## If @var{x} is a matrix, compute the mean for each column and return them
 ## in a row vector.
 ##
-## With the optional argument @var{opt}, the kind of mean computed can be
-## selected.  The following options are recognized:
+## The optional argument @var{opt} selects the type of mean to compute.
+## The following options are recognized:
 ##
-## @table @code
-## @item "a"
-## Compute the (ordinary) arithmetic mean.  This is the default.
+## @table @asis
+## @item @qcode{"a"}
+## Compute the (ordinary) arithmetic mean.  [default]
 ##
-## @item "g"
+## @item @qcode{"g"}
 ## Compute the geometric mean.
 ##
-## @item "h"
+## @item @qcode{"h"}
 ## Compute the harmonic mean.
 ## @end table
 ##
-## If the optional argument @var{dim} is supplied, work along dimension
-## @var{dim}.
+## If the optional argument @var{dim} is given, operate along this dimension.
 ##
 ## Both @var{dim} and @var{opt} are optional.  If both are supplied,
 ## either may appear first.
+## @seealso{median, mode}
 ## @end deftypefn
 
 ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
@@ -58,15 +61,23 @@
 
 function y = mean (x, opt1, opt2)
 
-  need_dim = 0;
+  if (nargin < 1 || nargin > 3)
+    print_usage ();
+  endif
+
+  if (! (isnumeric (x) || islogical (x)))
+    error ("mean: X must be a numeric vector or matrix");
+  endif
+
+  need_dim = false;
 
   if (nargin == 1)
     opt = "a";
-    need_dim = 1;
+    need_dim = true;
   elseif (nargin == 2)
     if (ischar (opt1))
       opt = opt1;
-      need_dim = 1;
+      need_dim = true;
     else
       dim = opt1;
       opt = "a";
@@ -79,47 +90,69 @@ function y = mean (x, opt1, opt2)
       opt = opt2;
       dim = opt1;
     else
-      error ("mean: expecting opt to be a string");
+      error ("mean: OPT must be a string");
     endif
   else
     print_usage ();
   endif
 
+  nd = ndims (x);
+  sz = size (x);
   if (need_dim)
-    t = find (size (x) != 1);
-    if (isempty (t))
-      dim = 1;
-    else
-      dim = t(1);
+    ## Find the first non-singleton dimension.
+    (dim = find (sz > 1, 1)) || (dim = 1);
+  else
+    if (!(isscalar (dim) && dim == fix (dim))
+      || !(1 <= dim && dim <= nd))
+      error ("mean: DIM must be an integer and a valid dimension");
     endif
   endif
 
-  if (dim > ndims (x))
-    n = 1;
-  else
-    sz = size (x);
-    n = sz (dim);
-  endif
+  n = sz(dim);
 
   if (strcmp (opt, "a"))
     y = sum (x, dim) / n;
   elseif (strcmp (opt, "g"))
-    y = prod (x, dim) .^ (1/n);
+    if (all (x(:) >= 0))
+      y = exp (sum (log (x), dim) ./ n);
+    else
+      error ("mean: X must not contain any negative values");
+    endif
   elseif (strcmp (opt, "h"))
     y = n ./ sum (1 ./ x, dim);
   else
-    error ("mean: option `%s' not recognized", opt);
+    error ("mean: option '%s' not recognized", opt);
   endif
 
 endfunction
 
+
 %!test
 %! x = -10:10;
 %! y = x';
 %! z = [y, y+10];
-%! assert(mean (x) == 0 && mean (y) == 0 && mean (z) == [0, 10]);
+%! assert (mean (x), 0);
+%! assert (mean (y), 0);
+%! assert (mean (z), [0, 10]);
 
-%!error mean ();
+## Test small numbers
+%!assert (mean (repmat (0.1,1,1000), "g"), 0.1, 20*eps)
 
-%!error mean (1, 2, 3);
+%!assert (mean (magic (3), 1), [5, 5, 5])
+%!assert (mean (magic (3), 2), [5; 5; 5])
+%!assert (mean ([2 8], "g"), 4)
+%!assert (mean ([4 4 2], "h"), 3)
+%!assert (mean (logical ([1 0 1 1])), 0.75)
+%!assert (mean (single ([1 0 1 1])), single (0.75))
+
+%% Test input validation
+%!error mean ()
+%!error mean (1, 2, 3, 4)
+%!error mean ({1:5})
+%!error mean (1, 2, 3)
+%!error mean (1, ones (2,2))
+%!error mean (1, 1.5)
+%!error mean (1, 0)
+%!error mean (1, 3)
+%!error mean (1, "b")
 
