@@ -1,5 +1,4 @@
-## Copyright (C) 1995, 1996, 1997, 1998, 2000, 2002, 2004, 2005, 2006,
-##               2007 Kurt Hornik
+## Copyright (C) 1995-2013 Kurt Hornik
 ## Copyright (C) 2009 Jaroslav Hajek
 ##
 ## This file is part of Octave.
@@ -19,15 +18,18 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} range (@var{x})
+## @deftypefn  {Function File} {} range (@var{x})
 ## @deftypefnx {Function File} {} range (@var{x}, @var{dim})
-## If @var{x} is a vector, return the range, i.e., the difference
-## between the maximum and the minimum, of the input data.
+## Return the range, i.e., the difference between the maximum and the minimum
+## of the input data.  If @var{x} is a vector, the range is calculated over
+## the elements of @var{x}.  If @var{x} is a matrix, the range is calculated
+## over each column of @var{x}.
 ##
-## If @var{x} is a matrix, do the above for each column of @var{x}.
+## If the optional argument @var{dim} is given, operate along this dimension.
 ##
-## If the optional argument @var{dim} is supplied, work along dimension
-## @var{dim}.
+## The range is a quickly computed measure of the dispersion of a data set, but
+## is less accurate than @code{iqr} if there are outlying data points.
+## @seealso{iqr, std}
 ## @end deftypefn
 
 ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
@@ -35,12 +37,26 @@
 
 function y = range (x, dim)
 
-  if (nargin == 1)
-    y = max (x) - min (x);
-  elseif (nargin == 2)
-    y = max (x, [], dim) - min (x, [], dim);
-  else
+  if (nargin < 1 || nargin > 2)
     print_usage ();
   endif
 
+  if (nargin == 1)
+    y = max (x) - min (x);
+  else
+    y = max (x, [], dim) - min (x, [], dim);
+  endif
+
 endfunction
+
+
+%!assert (range (1:10), 9)
+%!assert (range (single (1:10)), single (9))
+%!assert (range (magic (3)), [5, 8, 5])
+%!assert (range (magic (3), 2), [7; 4; 7])
+%!assert (range (2), 0)
+
+%% Test input validation
+%!error range ()
+%!error range (1, 2, 3)
+
