@@ -1,4 +1,4 @@
-## Copyright (C) 1996-2011 Kurt Hornik
+## Copyright (C) 1996-2013 Kurt Hornik
 ##
 ## This file is part of Octave.
 ##
@@ -42,8 +42,8 @@ function [pval, chisq, df] = mcnemar_test (x)
 
   if (! (min (size (x)) > 1) && issquare (x))
     error ("mcnemar_test: X must be a square matrix of size > 1");
-  elseif (! (all (all (x >= 0)) && all (all (x == round (x)))))
-    error ("mcnemar_test: all entries of X must be nonnegative integers");
+  elseif (! (all (all (x >= 0)) && all (all (x == fix (x)))))
+    error ("mcnemar_test: all entries of X must be non-negative integers");
   endif
 
   r = rows (x);
@@ -63,5 +63,3 @@ function [pval, chisq, df] = mcnemar_test (x)
 
 endfunction
 
-
-
